@@ -164,6 +164,18 @@
 //!
 //! Patches to improve Windows support in this library are welcome.
 //!
+//! # Features
+//!
+//! There are several feature flags that control how much is available as part of the crate, some
+//! enabled by default.
+//!
+//! * `channel`: (enabled by default) The [Channel][crate::low_level::channel] synchronization
+//!   primitive for exporting data out of signal handlers.
+//! * `iterator`: (enabled by default) An [Signals iterator][crate::iterator::Signals] that
+//!   provides a convenient interface for receiving signals in rust-friendly way.
+//! * `extended-siginfo` adds support for providing extra information as part of the iterator
+//!   interface.
+//!
 //! # Examples
 //!
 //! ## Using a flag to terminate a loop-based application
@@ -218,7 +230,6 @@
 //! # fn reload_config(&self) {}
 //! # fn print_stats(&self) {}
 //! # }
-//!
 //! # pub
 //! fn main() -> Result<(), Error> {
 //!     // Make sure double CTRL+C and similar kills
@@ -333,6 +344,7 @@
 
 pub mod flag;
 #[cfg(all(not(windows), feature = "iterator"))]
+#[cfg_attr(docsrs, doc(cfg(all(not(windows), feature = "iterator"))))]
 pub mod iterator;
 pub mod low_level;
 
